Diff Coverage

# Diff Coverage Report

Diff: HEAD^ HEAD, staged and unstaged changes

- Total: 2 lines
- Missing: 2 lines
- Coverage: 0%

Source File | Diff Coverage (%) | Missing Lines
--- | --- | ---
dcov/violationsreporters/violations_reporter.py | 0.0% | 236
pyproject.toml | 0.0% | 3

dcov/violationsreporters/violations_reporter.py

    232
    233
    234
    235
    236
    237
    238
    239
    240
                    # difference between changed_lines and line_nodes
                    df = set(changed_lines).difference(measured)
                    # intersection between changed_lines and line_nodes
                    it = set(changed_lines).intersection(measured)

                    violations = {
                        Violation(int(line), None)
                        for line in df
                    }

pyproject.toml

    1
    2
    3
    4
    5
    6
    7
    [tool.poetry]
    name = "dcov"
    version = "1.0.6"
    description = "Modify diff algorithm"
    authors = ["See Contributors"]
    homepage = "https://github.com/xiak/dcov"
    repository = "https://github.com/xiak/dcov"